@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.61 2004/03/03 04:58:04 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.62.2.3 2004/03/24 02:12:47 muppetman Exp $
 #
 
 package Gtk2;
@@ -31,7 +31,7 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '1.038';
+our $VERSION = '1.040';
 
 our @ISA = qw(DynaLoader);
 
@@ -103,11 +103,10 @@ Gtk2 - Perl interface to the 2.x series of the Gimp Toolkit library
 
 =head1 ABSTRACT
 
-  Perl bindings to the 2.x series of the Gtk+ widget set.
-  This module allows you to write graphical user interfaces in a 
-  perlish and object-oriented way, freeing you from the casting
-  and memory management in C, yet remaining very close in spirit
-  to original API.
+Perl bindings to the 2.x series of the Gtk+ widget set.  This module
+allows you to write graphical user interfaces in a perlish and
+object-oriented way, freeing you from the casting and memory management
+in C, yet remaining very close in spirit to original API.
 
 =head1 DESCRIPTION
 
