@@ -16,8 +16,7 @@
 
 package images;
 
-use constant FALSE => 0;
-use constant TRUE => 1;
+use Glib qw(TRUE FALSE);
 use Gtk2;
 use strict;
 
